==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/EventBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventBuilder extends EventFluentImpl<EventBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Event,EventBuilder> {

    EventFluent<?> fluent;
    Boolean validationEnabled;

    public EventBuilder() {
        this(true);
    }

    public EventBuilder(Boolean validationEnabled) {
        this(new Event(), validationEnabled);
    }

    public EventBuilder(EventFluent<?> fluent) {
        this(fluent, true);
    }

    public EventBuilder(EventFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Event(), validationEnabled);
    }

    public EventBuilder(EventFluent<?> fluent,Event instance) {
        this(fluent, instance, true);
    }

    public EventBuilder(EventFluent<?> fluent,Event instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withCount(instance.getCount()); 
        fluent.withEventTime(instance.getEventTime()); 
        fluent.withFirstTimestamp(instance.getFirstTimestamp()); 
        fluent.withInvolvedObject(instance.getInvolvedObject()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLastTimestamp(instance.getLastTimestamp()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withReason(instance.getReason()); 
        fluent.withRelated(instance.getRelated()); 
        fluent.withReportingComponent(instance.getReportingComponent()); 
        fluent.withReportingInstance(instance.getReportingInstance()); 
        fluent.withSeries(instance.getSeries()); 
        fluent.withSource(instance.getSource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventBuilder(Event instance) {
        this(instance,true);
    }

    public EventBuilder(Event instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withApiVersion(instance.getApiVersion()); 
        this.withCount(instance.getCount()); 
        this.withEventTime(instance.getEventTime()); 
        this.withFirstTimestamp(instance.getFirstTimestamp()); 
        this.withInvolvedObject(instance.getInvolvedObject()); 
        this.withKind(instance.getKind()); 
        this.withLastTimestamp(instance.getLastTimestamp()); 
        this.withMessage(instance.getMessage()); 
        this.withMetadata(instance.getMetadata()); 
        this.withReason(instance.getReason()); 
        this.withRelated(instance.getRelated()); 
        this.withReportingComponent(instance.getReportingComponent()); 
        this.withReportingInstance(instance.getReportingInstance()); 
        this.withSeries(instance.getSeries()); 
        this.withSource(instance.getSource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public Event build() {
        Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getCount(),fluent.getEventTime(),fluent.getFirstTimestamp(),fluent.getInvolvedObject(),fluent.getKind(),fluent.getLastTimestamp(),fluent.getMessage(),fluent.getMetadata(),fluent.getReason(),fluent.getRelated(),fluent.getReportingComponent(),fluent.getReportingInstance(),fluent.getSeries(),fluent.getSource(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventBuilder that = (EventBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.4.0-sources.jar: io/fabric8/kubernetes/api/model/EventBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventBuilder extends io.fabric8.kubernetes.api.model.EventFluentImpl<io.fabric8.kubernetes.api.model.EventBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.Event,io.fabric8.kubernetes.api.model.EventBuilder> {

    io.fabric8.kubernetes.api.model.EventFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public EventBuilder() {
        this(true);
    }

    public EventBuilder(java.lang.Boolean validationEnabled) {
        this(new Event(), validationEnabled);
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.EventFluent<?> fluent) {
        this(fluent, true);
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.EventFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new Event(), validationEnabled);
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.EventFluent<?> fluent,io.fabric8.kubernetes.api.model.Event instance) {
        this(fluent, instance, true);
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.EventFluent<?> fluent,io.fabric8.kubernetes.api.model.Event instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withCount(instance.getCount()); 
        fluent.withEventTime(instance.getEventTime()); 
        fluent.withFirstTimestamp(instance.getFirstTimestamp()); 
        fluent.withInvolvedObject(instance.getInvolvedObject()); 
        fluent.withKind(instance.getKind()); 
        fluent.withLastTimestamp(instance.getLastTimestamp()); 
        fluent.withMessage(instance.getMessage()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withReason(instance.getReason()); 
        fluent.withRelated(instance.getRelated()); 
        fluent.withReportingComponent(instance.getReportingComponent()); 
        fluent.withReportingInstance(instance.getReportingInstance()); 
        fluent.withSeries(instance.getSeries()); 
        fluent.withSource(instance.getSource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.Event instance) {
        this(instance,true);
    }

    public EventBuilder(io.fabric8.kubernetes.api.model.Event instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withApiVersion(instance.getApiVersion()); 
        this.withCount(instance.getCount()); 
        this.withEventTime(instance.getEventTime()); 
        this.withFirstTimestamp(instance.getFirstTimestamp()); 
        this.withInvolvedObject(instance.getInvolvedObject()); 
        this.withKind(instance.getKind()); 
        this.withLastTimestamp(instance.getLastTimestamp()); 
        this.withMessage(instance.getMessage()); 
        this.withMetadata(instance.getMetadata()); 
        this.withReason(instance.getReason()); 
        this.withRelated(instance.getRelated()); 
        this.withReportingComponent(instance.getReportingComponent()); 
        this.withReportingInstance(instance.getReportingInstance()); 
        this.withSeries(instance.getSeries()); 
        this.withSource(instance.getSource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.Event build() {
        Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getCount(),fluent.getEventTime(),fluent.getFirstTimestamp(),fluent.getInvolvedObject(),fluent.getKind(),fluent.getLastTimestamp(),fluent.getMessage(),fluent.getMetadata(),fluent.getReason(),fluent.getRelated(),fluent.getReportingComponent(),fluent.getReportingInstance(),fluent.getSeries(),fluent.getSource(),fluent.getType());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventBuilder that = (EventBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
